==> order-center-domain-3.0.0-CLOUD-DEV-20221101.113309-125-sources.jar: com/tydic/dyc/oc/model/order/qrybo/UocOrdLogisticsRelaQryBo.java <==
package com.tydic.dyc.oc.model.order.qrybo;

import com.tydic.dyc.base.bo.BasePageReqBo;
import com.tydic.utils.generatedoc.annotation.DocField;
import lombok.Data;
import lombok.EqualsAndHashCode;

import java.util.Date;

/**
 * 标题:UocOrdLogisticsRelaQryBo
 * 说明:收货信息领域对象
 * 时间:2022-02-21 19:10
 * 作者:罗有
 **/
@EqualsAndHashCode(callSuper = true)
@Data
public class UocOrdLogisticsRelaQryBo extends BasePageReqBo {
	private static final long serialVersionUID =  -5606594342479539198L;

	@DocField(value = "收货地址ID")
	private Long contactId;

	@DocField(value = "订单id")
	private Long orderId;

	@DocField(value = "联系人国家编号")
	private String contactCountryId;

	@DocField(value = "联系人国家名称")
	private String contactCountryName;

	@DocField(value = "联系人省份编号")
	private String contactProvinceId;

	@DocField(value = "联系人省份名称")
	private String contactProvinceName;

	@DocField(value = "联系人地市编号")
	private String contactCityId;

	@DocField(value = "联系人地市名称")
	private String contactCityName;

	@DocField(value = "联系人区县编号")
	private String contactCountyId;

	@DocField(value = "联系人区县名称")
	private String contactCountyName;

	@DocField(value = "联系人乡镇编号")
	private String contactTownId;

	@DocField(value = "联系人乡镇名称")
	private String contactTown;

	@DocField(value = "收货人地址")
	private String contactAddress;

	@DocField(value = "联系人公司")
	private String contactCompany;

	@DocField(value = "联系人名称")
	private String contactName;

	@DocField(value = "联系人固话")
	private String contactFixPhone;

	@DocField(value = "联系人邮件")
	private String contactEmail;

	@DocField(value = "联系人手机")
	private String contactMobile;

	@DocField(value = "创建时间")
	private Date createTime;

	@DocField(value = "创建时间 开始")
	private Date createTimeStart;

	@DocField(value = "创建时间 结束")
	private Date createTimeEnd;

	@DocField(value = "创建工号")
	private String createOperId;

	@DocField(value = "更新时间")
	private Date updateTime;

	@DocField(value = "更新时间 开始")
	private Date updateTimeStart;

	@DocField(value = "更新时间 结束")
	private Date updateTimeEnd;

	@DocField(value = "更新工号")
	private String updateOperId;

	@DocField(value = "备注")
	private String remark;

	@DocField(value = "删除标志1已删除")
	private Integer delTag;

	@DocField(value = "排序")
	private String orderBy;

}

==> order-center-domain-3.1.0-CLOUD-DEV-20230809.092853-75-sources.jar: com/tydic/dyc/oc/model/order/qrybo/UocOrdLogisticsRelaQryBo.java <==
package com.tydic.dyc.oc.model.order.qrybo;

import com.tydic.dyc.base.bo.BasePageReqBo;

import lombok.Data;
import lombok.EqualsAndHashCode;

import java.util.Date;

/**
 * 标题:UocOrdLogisticsRelaQryBo
 * 说明:收货信息领域对象
 * 时间:2022-02-21 19:10
 * 作者:罗有
 **/
@EqualsAndHashCode(callSuper = true)
@Data
public class UocOrdLogisticsRelaQryBo extends BasePageReqBo {
	private static final long serialVersionUID =  -5606594342479539198L;

	//收货地址ID")
	private Long contactId;

	//订单id")
	private Long orderId;

	//联系人国家编号")
	private String contactCountryId;

	//联系人国家名称")
	private String contactCountryName;

	//联系人省份编号")
	private String contactProvinceId;

	//联系人省份名称")
	private String contactProvinceName;

	//联系人地市编号")
	private String contactCityId;

	//联系人地市名称")
	private String contactCityName;

	//联系人区县编号")
	private String contactCountyId;

	//联系人区县名称")
	private String contactCountyName;

	//联系人乡镇编号")
	private String contactTownId;

	//联系人乡镇名称")
	private String contactTown;

	//收货人地址")
	private String contactAddress;

	//联系人公司")
	private String contactCompany;

	//联系人名称")
	private String contactName;

	//联系人固话")
	private String contactFixPhone;

	//联系人邮件")
	private String contactEmail;

	//联系人手机")
	private String contactMobile;

	//创建时间")
	private Date createTime;

	//创建时间 开始")
	private Date createTimeStart;

	//创建时间 结束")
	private Date createTimeEnd;

	//创建工号")
	private String createOperId;

	//更新时间")
	private Date updateTime;

	//更新时间 开始")
	private Date updateTimeStart;

	//更新时间 结束")
	private Date updateTimeEnd;

	//更新工号")
	private String updateOperId;

	//备注")
	private String remark;

	//删除标志1已删除")
	private Integer delTag;

	//排序")
	private String orderBy;

}
